==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/ka_GE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "თქვენთან გაზიარებული",
    "Nothing shared with you yet" : "თქვენთან ჯერ არაფერია გაზიარებული",
    "Files and folders others share with you will show up here" : "აქ გამოჩნდება ფაილები და დირექტორიები, რომლებსაც სხვები თქვენთან აზიარებენ",
    "Shared with others" : "სხვასთან გაზიარებული",
    "Nothing shared yet" : "ჯერ არაფერი გაზიარებულა",
    "Files and folders you share will show up here" : "აქ გამოჩნდება ფაილები და დირექტორიები რომლებსაც აზიარებთ თქვენ",
    "Shared by link" : "ბმულით გაზიარებული",
    "No shared links" : "გაზიარებული ბმულები არაა",
    "Files and folders you share by link will show up here" : "აქ გამოჩნდება ფაილები და დირექტორიები რომლებსაც ბმულით აზიარებთ თქვენ",
    "Shares" : "გაზიარებები",
    "Restore" : "აღდგენა",
    "Move or copy" : "გადაიტანეთ ან დააკოპირეთ",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "წაშლა",
    "You can upload into this folder" : "შეგიძლიათ ატვირთოთ ამ დირექტორიაში",
    "No compatible server found at {remote}" : "თავსებადი სერვერი {remote}-ზე ვერ იქნა ნაპოვნი",
    "Invalid server URL" : "არასწორი სერვერის URL",
    "Failed to add the public link to your Nextcloud" : "საზოგადო ბმულის დამატება თქვენს Nextcloud-ზე ვერ მოხერხდა",
    "No expiration date set" : "გაუქმების თარიღი არაა დაყენებული",
    "Shared by" : "აზიარებს",
    "File shares" : "ფაილის გაზიარებები",
    "Downloaded via public link" : "გადმოწერილია საზოგადო ბმულით",
    "Downloaded by {email}" : "გადმოწერა {email}-მ",
    "{file} downloaded via public link" : "{file} გადმოწერილია საზოგადო ბმულით",
    "{email} downloaded {file}" : "{email}-მ გადმოწერა {file}",
    "Shared with group {group}" : "გაზიარებულია ჯგუფთან {group}",
    "Removed share for group {group}" : "გაზიარება {group} ჯგუფთან შეწყდა",
    "{actor} shared with group {group}" : "{actor} მომხმარებელმა გააზიარა ჯგუფთან {group}",
    "{actor} removed share for group {group}" : "{actor} მომხმარებელმა შეწყვიტა გაზიარება ჯგუფთან {group}",
    "You shared {file} with group {group}" : "თქვენ გააზიარეთ {file} ჯგუფთან {group}",
    "You removed group {group} from {file}" : "თქვენ მოაშორეთ ჯგუფი {group} ფაილს {file}",
    "{actor} shared {file} with group {group}" : "{actor} მომხმარებელმა გააზიარა ფაილი {file} ჯგუფთან {group}",
    "{actor} removed group {group} from {file}" : "{actor} მომხმარებელმა მოაშორა ჯგუფი {group} ფაილს {file}",
    "Shared as public link" : "გააზიარა როგორც საზოგადო ბმული",
    "Removed public link" : "გააუქმა საზოგადო ბმული",
    "Public link expired" : "საზოგადო ბმულს გაუვიდა ვადა",
    "{actor} shared as public link" : "{actor} მომხმარებელმა გააზიარა საზოგადო ბმულად",
    "{actor} removed public link" : "{actor} მომხმარებელმა გააუქმა საზოგადო ბმული",
    "Public link of {actor} expired" : "{actor} მომხმარებლის საზოგადო ბმულს გაუვიდა ვადა",
    "You shared {file} as public link" : "თქვენ საზოგადო ბმულის სახით გააზიარეთ {file}",
    "You removed public link for {file}" : "თქვენ გააუქმეთ საზოგადო ბმული ფაილისთვის {file}",
    "Public link expired for {file}" : "საზოგადო ბმულს ფაილისთვის {file} გაუვიდა ვადა",
    "{actor} shared {file} as public link" : "{actor} მომხმარებელმა საზოგადო ბმულის სახით გააზიარა {file}",
    "{actor} removed public link for {file}" : "{actor} მომხმარებელმა გააუქმა საზოგადო ბმული ფაილისთვის {file}",
    "Public link of {actor} for {file} expired" : "{actor} მომხმარებლის საზოგადო ბმულს ფაილზე {file} გაუვიდა ვადა",
    "{user} accepted the remote share" : "{user} მომხმარებელმა მიიღო დისტანციური გაზიარება",
    "{user} declined the remote share" : "{user} მომხმარებელმა უარყო დისტანციური გაზიარება",
    "You received a new remote share {file} from {user}" : "თქვენ მიიღეთ ახალი დისტანციური გაზიარება {file} მომხმარებლისგან {user}",
    "{user} accepted the remote share of {file}" : "{user} მომხმარებელმა მიიღო დისტანციური გაზიარება ფაილზე {file}",
    "{user} declined the remote share of {file}" : "{user} მომხმარებელმა უარყო დისტანციური გაზიარება ფალზე {file}",
    "{user} unshared {file} from you" : "{user} მომხმარებელმა შეწყვიტა ფაილის {file} გაზიარება თქვენთან",
    "Shared with {user}" : "გაზიარებული მომხმარებელთან {user}",
    "Removed share for {user}" : "შეწყდა გაზიარება მომხმარებელთან {user}",
    "{actor} shared with {user}" : "{actor} მომხმარებელმა გააზიარა მომხმარებელთან {user}",
    "{actor} removed share for {user}" : "{actor} მომხმარებელმა შეწყვიტა გაზიარება მომხმარებელთან {user}",
    "Shared by {actor}" : "გააზიარა მომხმარებელმა {actor}",
    "{actor} removed share" : "{actor} მომხმარებელმა შეწყვიტა გაზიარება",
    "You shared {file} with {user}" : "თქვენ გააზიარეთ ფაილი {file} მომხმარებელთან {user}",
    "You removed {user} from {file}" : "თქვენ ჩამოაშორეთ მომხმარებელი {user} ფაილს {file}",
    "{actor} shared {file} with {user}" : "{actor} მომხმარებელმა გააზიარა ფაილი {file} მომხმარებელთან {user}",
    "{actor} removed {user} from {file}" : "{actor} მომხმარებელმა ჩამოაშორა მომხმარებელი {user} ფაილს {file}",
    "{actor} shared {file} with you" : "{actor} მომხმარებელმა თქვენთან გააზიარა {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "ელ-ფოსტით ან საზოგადო ბმულით გაზიარბული ფაილი ან დირექტორია  <strong>გადმოწერილ იქნა</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "ფაილი ან დირექტორია გაზიარდა <strong>სხვა სერვერიდან</strong>",
    "Files" : "ფაილები",
    "A file or folder has been <strong>shared</strong>" : "ფაილი ან დირექტორია <strong>გაზიარებულ იქნა</strong>",
    "Wrong share ID, share doesn't exist" : "არასწორი გაზიარების ID, გაზიარება არ არსებობს",
    "Could not delete share" : "გაზიარების გაუქმება ვერ მოხერხდა",
    "Please specify a file or folder path" : "გთხოვთ მიუთითოთ ფაილის ან დირექტორიის მისამართი",
    "Wrong path, file/folder doesn't exist" : "არასწორი მისამართი, ფაილი/დირქტორია არ არსებობს",
    "Could not create share" : "გაზიარება ვერ შეიქმნა",
    "Please specify a valid user" : "გთხოვთ მიუთითოთ სწორი მომხმარებელი",
    "Group sharing is disabled by the administrator" : "ჯგუფური გაზიარება ადმინისტრატორის მიერ არაა ამოქმედებული",
    "Please specify a valid group" : "გთხოვთ მიუთითოთ სწორი ჯგუფი",
    "Public link sharing is disabled by the administrator" : "საზოგადო ბმულად გაზიარება ადმინისტრატორის მიერ არაა ამოქმდებეული",
    "Public upload disabled by the administrator" : "საზოგადო ატვირთვა ადმინისტრატორის მიერ არაა ამოქმედებული",
    "Public upload is only possible for publicly shared folders" : "საზოგადო ატვირთვა შესაძლებელია მხოლოდ საზოგადოდ გაზიარებულ დირექტორიებზე",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "You cannot share to a Circle if the app is not enabled" : "წრეს ვერ გაუზიარებთ თუ აპლიკაცია არაა მოქმედი",
    "Please specify a valid circle" : "გთხოვთ მიუთითოთ სწორი წრე",
    "Unknown share type" : "ამოუცნობი გაზიარების სახეობა",
    "Not a directory" : "არაა დირექტორია",
    "Could not lock path" : "მისამართი ვერ ჩაიკეტა",
    "Wrong or no update parameter given" : "არასწორი ან განახლების პარამეტრის არარსებობა",
    "Can't change permissions for public share links" : "უფლებები საზოგადოდ გაზიარებულ ბმულზე ვერ შეიცვალა",
    "shared by %s" : "გააზიარა მომხმარებელმა %s",
    "Direct link" : "პირდაპირი ბმული",
    "Add to your Nextcloud" : "თქვენს Nextcloud-ში დამატება",
    "Share API is disabled" : "გაზიარების API არაა მოქმედი",
    "File sharing" : "ფაილების გაზიარება",
    "Accept" : "მიღება",
    "Sharing" : "გაზიარება",
    "Allow editing" : "შეცვლის ნების დართვა",
    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
    "Set expiration date" : "მიუთითეთ ვადის გასვლის დრო",
    "Unshare" : "გაზიარების შეწყვეტა",
    "group" : "ჯგუფი",
    "remote" : "დისტანციური",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Password protection" : "პაროლით თავდაცვა",
    "Enter a password" : "შეიყვანეთ პაროლი",
    "Cancel" : "უარყოფა",
    "Read only" : "მხოლოდ-კითხვადი",
    "Allow upload and editing" : "ატვირთვისა და ცვლილების უფლებების მინიჭება",
    "File drop (upload only)" : "ფაილის ჩაგდება (მხოლოდ ატვირთვა)",
    "Password protect" : "პაროლით დაცვა",
    "Share link" : "ბმულის გაზიარება",
    "Resharing is not allowed" : "ხელახალი გაზიარება არაა დაშვებული",
    "Shared" : "გაზიარებული",
    "Share" : "გაზიარება",
    "Shared with" : "გაზიარებულია",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner} მომხმარებლის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner} მომხმარებლის მიერ",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ მოიძებნა",
    "Name" : "სახელი",
    "Share time" : "გაზიარების დრო",
    "Expiration date" : "გაუქმების თარიღი",
    "Sorry, this link doesn’t seem to work anymore." : "ბოდიში, ეს ბმული აღარ მოქმედებს.",
    "Reasons might be:" : "შესაძლო მიზეზებია:",
    "the item was removed" : "ობიექტი გაუქმდა",
    "the link expired" : "ბმულს ვადა გაუვიდა",
    "sharing is disabled" : "გაზიარება არაა მოქმედი",
    "For more info, please ask the person who sent this link." : "მეტი ინფრმაციისთვის, გთხოვთ ჰკითხოთ ადამიანს ვინც გამოგიგზავნათ ეს ბმული.",
    "Download %s" : "%s-ის ჩამოტვირთვა",
    "Upload files to %s" : "ფაილების ატვირთვა %s-ში",
    "Select or drop files" : "აირჩიეთ ან გადმოიტანეთ ფაილები",
    "Uploaded files:" : "ფაილების ატვირთვა:",
    "invalid permissions" : "არასწორი უფლებები"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/ka_GE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "თქვენთან გაზიარებული",
    "Nothing shared with you yet" : "თქვენთან ჯერ არაფერია გაზიარებული",
    "Files and folders others share with you will show up here" : "აქ გამოჩნდება ფაილები და დირექტორიები, რომლებსაც სხვები თქვენთან აზიარებენ",
    "Shared with others" : "სხვასთან გაზიარებული",
    "Nothing shared yet" : "ჯერ არაფერი გაზიარებულა",
    "Files and folders you share will show up here" : "აქ გამოჩნდება ფაილები და დირექტორიები რომლებსაც აზიარებთ თქვენ",
    "Shared by link" : "ბმულით გაზიარებული",
    "No shared links" : "გაზიარებული ბმულები არაა",
    "Files and folders you share by link will show up here" : "აქ გამოჩნდება ფაილები და დირექტორიები რომლებსაც ბმულით აზიარებთ თქვენ",
    "Shares" : "გაზიარებები",
    "Restore" : "აღდგენა",
    "Move or copy" : "გადაიტანეთ ან დააკოპირეთ",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "წაშლა",
    "You can upload into this folder" : "შეგიძლიათ ატვირთოთ ამ დირექტორიაში",
    "No compatible server found at {remote}" : "თავსებადი სერვერი {remote}-ზე ვერ იქნა ნაპოვნი",
    "Invalid server URL" : "არასწორი სერვერის URL",
    "Failed to add the public link to your Nextcloud" : "საზოგადო ბმულის დამატება თქვენს Nextcloud-ზე ვერ მოხერხდა",
    "No expiration date set" : "გაუქმების თარიღი არაა დაყენებული",
    "Shared by" : "აზიარებს",
    "File shares" : "ფაილის გაზიარებები",
    "Downloaded via public link" : "გადმოწერილია საზოგადო ბმულით",
    "Downloaded by {email}" : "გადმოწერა {email}-მ",
    "{file} downloaded via public link" : "{file} გადმოწერილია საზოგადო ბმულით",
    "{email} downloaded {file}" : "{email}-მ გადმოწერა {file}",
    "Shared with group {group}" : "გაზიარებულია ჯგუფთან {group}",
    "Removed share for group {group}" : "გაზიარება {group} ჯგუფთან შეწყდა",
    "{actor} shared with group {group}" : "{actor} მომხმარებელმა გააზიარა ჯგუფთან {group}",
    "{actor} removed share for group {group}" : "{actor} მომხმარებელმა შეწყვიტა გაზიარება ჯგუფთან {group}",
    "You shared {file} with group {group}" : "თქვენ გააზიარეთ {file} ჯგუფთან {group}",
    "You removed group {group} from {file}" : "თქვენ მოაშორეთ ჯგუფი {group} ფაილს {file}",
    "{actor} shared {file} with group {group}" : "{actor} მომხმარებელმა გააზიარა ფაილი {file} ჯგუფთან {group}",
    "{actor} removed group {group} from {file}" : "{actor} მომხმარებელმა მოაშორა ჯგუფი {group} ფაილს {file}",
    "Shared as public link" : "გააზიარა როგორც საზოგადო ბმული",
    "Removed public link" : "გააუქმა საზოგადო ბმული",
    "Public link expired" : "საზოგადო ბმულს გაუვიდა ვადა",
    "{actor} shared as public link" : "{actor} მომხმარებელმა გააზიარა საზოგადო ბმულად",
    "{actor} removed public link" : "{actor} მომხმარებელმა გააუქმა საზოგადო ბმული",
    "Public link of {actor} expired" : "{actor} მომხმარებლის საზოგადო ბმულს გაუვიდა ვადა",
    "You shared {file} as public link" : "თქვენ საზოგადო ბმულის სახით გააზიარეთ {file}",
    "You removed public link for {file}" : "თქვენ გააუქმეთ საზოგადო ბმული ფაილისთვის {file}",
    "Public link expired for {file}" : "საზოგადო ბმულს ფაილისთვის {file} გაუვიდა ვადა",
    "{actor} shared {file} as public link" : "{actor} მომხმარებელმა საზოგადო ბმულის სახით გააზიარა {file}",
    "{actor} removed public link for {file}" : "{actor} მომხმარებელმა გააუქმა საზოგადო ბმული ფაილისთვის {file}",
    "Public link of {actor} for {file} expired" : "{actor} მომხმარებლის საზოგადო ბმულს ფაილზე {file} გაუვიდა ვადა",
    "{user} accepted the remote share" : "{user} მომხმარებელმა მიიღო დისტანციური გაზიარება",
    "{user} declined the remote share" : "{user} მომხმარებელმა უარყო დისტანციური გაზიარება",
    "You received a new remote share {file} from {user}" : "თქვენ მიიღეთ ახალი დისტანციური გაზიარება {file} მომხმარებლისგან {user}",
    "{user} accepted the remote share of {file}" : "{user} მომხმარებელმა მიიღო დისტანციური გაზიარება ფაილზე {file}",
    "{user} declined the remote share of {file}" : "{user} მომხმარებელმა უარყო დისტანციური გაზიარება ფალზე {file}",
    "{user} unshared {file} from you" : "{user} მომხმარებელმა შეწყვიტა ფაილის {file} გაზიარება თქვენთან",
    "Shared with {user}" : "გაზიარებული მომხმარებელთან {user}",
    "Removed share for {user}" : "შეწყდა გაზიარება მომხმარებელთან {user}",
    "{actor} shared with {user}" : "{actor} მომხმარებელმა გააზიარა მომხმარებელთან {user}",
    "{actor} removed share for {user}" : "{actor} მომხმარებელმა შეწყვიტა გაზიარება მომხმარებელთან {user}",
    "Shared by {actor}" : "გააზიარა მომხმარებელმა {actor}",
    "{actor} removed share" : "{actor} მომხმარებელმა შეწყვიტა გაზიარება",
    "You shared {file} with {user}" : "თქვენ გააზიარეთ ფაილი {file} მომხმარებელთან {user}",
    "You removed {user} from {file}" : "თქვენ ჩამოაშორეთ მომხმარებელი {user} ფაილს {file}",
    "{actor} shared {file} with {user}" : "{actor} მომხმარებელმა გააზიარა ფაილი {file} მომხმარებელთან {user}",
    "{actor} removed {user} from {file}" : "{actor} მომხმარებელმა ჩამოაშორა მომხმარებელი {user} ფაილს {file}",
    "{actor} shared {file} with you" : "{actor} მომხმარებელმა თქვენთან გააზიარა {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "ელ-ფოსტით ან საზოგადო ბმულით გაზიარბული ფაილი ან დირექტორია  <strong>გადმოწერილ იქნა</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "ფაილი ან დირექტორია გაზიარდა <strong>სხვა სერვერიდან</strong>",
    "Files" : "ფაილები",
    "A file or folder has been <strong>shared</strong>" : "ფაილი ან დირექტორია <strong>გაზიარებულ იქნა</strong>",
    "Wrong share ID, share doesn't exist" : "არასწორი გაზიარების ID, გაზიარება არ არსებობს",
    "Could not delete share" : "გაზიარების გაუქმება ვერ მოხერხდა",
    "Please specify a file or folder path" : "გთხოვთ მიუთითოთ ფაილის ან დირექტორიის მისამართი",
    "Wrong path, file/folder doesn't exist" : "არასწორი მისამართი, ფაილი/დირქტორია არ არსებობს",
    "Could not create share" : "გაზიარება ვერ შეიქმნა",
    "Please specify a valid user" : "გთხოვთ მიუთითოთ სწორი მომხმარებელი",
    "Group sharing is disabled by the administrator" : "ჯგუფური გაზიარება ადმინისტრატორის მიერ არაა ამოქმედებული",
    "Please specify a valid group" : "გთხოვთ მიუთითოთ სწორი ჯგუფი",
    "Public link sharing is disabled by the administrator" : "საზოგადო ბმულად გაზიარება ადმინისტრატორის მიერ არაა ამოქმდებეული",
    "Public upload disabled by the administrator" : "საზოგადო ატვირთვა ადმინისტრატორის მიერ არაა ამოქმედებული",
    "Public upload is only possible for publicly shared folders" : "საზოგადო ატვირთვა შესაძლებელია მხოლოდ საზოგადოდ გაზიარებულ დირექტორიებზე",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "You cannot share to a Circle if the app is not enabled" : "წრეს ვერ გაუზიარებთ თუ აპლიკაცია არაა მოქმედი",
    "Please specify a valid circle" : "გთხოვთ მიუთითოთ სწორი წრე",
    "Unknown share type" : "ამოუცნობი გაზიარების სახეობა",
    "Not a directory" : "არაა დირექტორია",
    "Could not lock path" : "მისამართი ვერ ჩაიკეტა",
    "Wrong or no update parameter given" : "არასწორი ან განახლების პარამეტრის არარსებობა",
    "shared by %s" : "გააზიარა მომხმარებელმა %s",
    "Direct link" : "პირდაპირი ბმული",
    "Share API is disabled" : "გაზიარების API არაა მოქმედი",
    "File sharing" : "ფაილების გაზიარება",
    "Accept" : "მიღება",
    "Sharing" : "გაზიარება",
    "Allow editing" : "შეცვლის ნების დართვა",
    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
    "Set expiration date" : "მიუთითეთ ვადის გასვლის დრო",
    "Unshare" : "გაზიარების შეწყვეტა",
    "group" : "ჯგუფი",
    "remote" : "დისტანციური",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Password protection" : "პაროლით თავდაცვა",
    "Enter a password" : "შეიყვანეთ პაროლი",
    "Cancel" : "უარყოფა",
    "Read only" : "მხოლოდ-კითხვადი",
    "Allow upload and editing" : "ატვირთვისა და ცვლილების უფლებების მინიჭება",
    "File drop (upload only)" : "ფაილის ჩაგდება (მხოლოდ ატვირთვა)",
    "Password protect" : "პაროლით დაცვა",
    "Share link" : "ბმულის გაზიარება",
    "Resharing is not allowed" : "ხელახალი გაზიარება არაა დაშვებული",
    "Shared" : "გაზიარებული",
    "Share" : "გაზიარება",
    "Shared with" : "გაზიარებულია",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner} მომხმარებლის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner} მომხმარებლის მიერ",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ მოიძებნა",
    "Name" : "სახელი",
    "Share time" : "გაზიარების დრო",
    "Expiration date" : "გაუქმების თარიღი",
    "Sorry, this link doesn’t seem to work anymore." : "ბოდიში, ეს ბმული აღარ მოქმედებს.",
    "Reasons might be:" : "შესაძლო მიზეზებია:",
    "the item was removed" : "ობიექტი გაუქმდა",
    "the link expired" : "ბმულს ვადა გაუვიდა",
    "sharing is disabled" : "გაზიარება არაა მოქმედი",
    "For more info, please ask the person who sent this link." : "მეტი ინფრმაციისთვის, გთხოვთ ჰკითხოთ ადამიანს ვინც გამოგიგზავნათ ეს ბმული.",
    "Download %s" : "%s-ის ჩამოტვირთვა",
    "Upload files to %s" : "ფაილების ატვირთვა %s-ში",
    "Select or drop files" : "აირჩიეთ ან გადმოიტანეთ ფაილები",
    "Uploaded files:" : "ფაილების ატვირთვა:",
    "Add to your Nextcloud" : "თქვენს Nextcloud-ში დამატება",
    "invalid permissions" : "არასწორი უფლებები",
    "Can't change permissions for public share links" : "უფლებები საზოგადოდ გაზიარებულ ბმულზე ვერ შეიცვალა"
},
"nplurals=2; plural=(n!=1);");
